% AISV article Template
% This LaTex template can be used in order to have a look similar to AISV article template.
%
% Version 0.1 2013/04/02 
% Fabio Tesser
% fabio.tesser@gmail.com
%
% Version 0.2 2014/02/13 
% Vincenzo Galatà
% Minor revisions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{aisv-article}[2009/02/25 v0.1 Paulius' modified article class]

% Passes and class options to the underlying article class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

% Load LaTeX's article class with the `titlepage' option so that \maketitle creates a title page, not just a title block
%\LoadClass[titlepage]{article}
\LoadClass{article}

% Redefine the page margins
% TODO: Adjust margins to your liking
%\RequirePackage[left=4cm,right=4cm,top=5cm,bottom=5cm]{geometry}
\RequirePackage[left=4cm,right=4cm,top=0cm,bottom=0cm]{geometry}

% header position
\setlength{\topmargin}{-1.26cm}
\setlength{\headsep}{3.35cm}
\setlength{\textheight}{19.6cm}

% Remove the numbers from all the headings (\section, \subsection, etc.)
%\setcounter{secnumdepth}{-1}

% small 9pt
% normal 10pt 
% large 12pt


\RequirePackage{sectsty,textcase}
%Force  section to upper case
%\allsectionsfont{\MakeTextUppercase}
\sectionfont{\normalsize \MakeTextUppercase}
\subsectionfont{\normalsize \it}
\subsubsectionfont{\normalsize \it}

\RequirePackage{titlesec}
%\titlespacing{command}{left spacing}{before spacing}{after spacing}[right]
%From the titlesec package
% spacing: how to read {12pt plus 4pt minus 2pt}
%           12pt is what we would like the spacing to be
%           plus 4pt means that TeX can stretch it by at most 4pt
%           minus 2pt means that TeX can shrink it by at most 2pt
%       This is one example of the concept of, 'glue', in TeX
\titlespacing{\section}{0pt}{12pt plus 4pt minus 2pt}{3pt plus 2pt minus 2pt}
\titlespacing{\subsection}{0pt}{6pt plus 4pt minus 2pt}{0pt plus 2pt minus 2pt}
\titlespacing{\subsubsection}{0pt}{6pt plus 4pt minus 2pt}{0pt plus 2pt minus 2pt}


% \RequirePackage{titlesec,textcase}
% \titleformat*{\section}{ \bf \MakeTextUppercase }
% \titleformat*{\subsection}{ \it}
% \titleformat*{\subsubsection}{\it}

% To modify the heading styles more thoroughly use the titlesec package
\RequirePackage{titlesec}
%\titlelabel{\thetitle.\quad}
%\makeatletter
\renewcommand{\@seccntformat}[1]{\csname the#1\endcsname.\hspace{4pt}}
%\makeatother

\newcommand{\authorheader}[1]{\gdef\@authorheader{#1}}%
\newcommand{\@authorheader}{\@latex@warning@no@line{No \noexpand\authorheader given}}

\newcommand{\shorttitle}[1]{\gdef\@shorttitle{#1}}%
\newcommand{\@shorttitle}{\@latex@warning@no@line{No \noexpand\shorttitle given}}

\newcommand{\affiliation}[1]{\gdef\@affiliation{#1}}%
\newcommand{\@affiliation}{\@latex@warning@no@line{No \noexpand\affiliation given}}

\newcommand{\authoremail}[1]{\gdef\@authoremail{#1}}%
\newcommand{\@authoremail}{\@latex@warning@no@line{No \noexpand\authoremail given}}

\newcommand{\issue}[1]{\gdef\@issue{#1}}%
\newcommand{\@issue}{\@latex@warning@no@line{No \noexpand\issue given}}

\newcommand{\rmnum}[1]{\romannumeral #1}
\newcommand{\Rmnum}[1]{\expandafter\@slowromancap\romannumeral #1@}
\newcommand{\titleheadertext}{Atti del \Rmnum{\@issue} Convegno dell'Associazione Italiana Scienze della Voce}

%times new roman
\RequirePackage{mathptmx}

%header
\RequirePackage{fancyhdr,ifthen}

\renewcommand\maketitle{
\begin{center}
\large{\textbf{\MakeTextUppercase{\@title}}}

\vspace{12pt}

\normalsize{\@author}

\small{\@affiliation}

\small{\textit{\@authoremail}}

\end{center}
\thispagestyle{firststyle}
}

% % This is taken into account from babel
% \renewcommand{\figurename}{Figura} 
% \renewcommand{\tablename}{Tabella}
% \renewcommand{\refname}{Bibliografia}

% no page numbers
\pagenumbering{gobble}

% fancy header for title page
\fancypagestyle{firststyle}{%
  \fancyhf{}% Clear header/footer
  \fancyhead[C]{\titleheadertext{}}% Your journal/note
  \renewcommand{\headrulewidth}{0pt}
}


% fancy header for other pages
\pagestyle{fancy}
\fancyhead{}
\fancyhf{}
\fancyhead[C]{\ifthenelse{\isodd{\value{page}}}{\@shorttitle}{\@authorheader}}
\renewcommand{\headrulewidth}{0pt}

%\RequirePackage{footmisc}
\renewcommand{\footnotesize}{\normalsize}
%\renewcommand\footnotelayout{\normalsize}

% TODO: If there are any other article modifications required, add them here.

% That's all, folks!
\endinput